package
module
Version:
v0.0.0
Opens a new window with list of versions in this module.
Published: Feb 7, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
• About Executor •
Installation •
Examples •
💻 About Executor
executor is your toolkit for simple, reliable and elegant concurrency in go.
🛠Installation
To install executor, run:
go get -u github.com/go-umbrella/executor
📚 Examples
Documentation
¶
type Executor interface {
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.